/* bz-installed-page.h
 *
 * Copyright 2025 Adam Masciola
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <adwaita.h>

G_BEGIN_DECLS

#define BZ_TYPE_INSTALLED_PAGE (bz_installed_page_get_type ())
G_DECLARE_FINAL_TYPE (BzInstalledPage, bz_installed_page, BZ, INSTALLED_PAGE, AdwBin)

GtkWidget *
bz_installed_page_new (void);

void
bz_installed_page_set_model (BzInstalledPage *self,
                             GListModel      *model);

GListModel *
bz_installed_page_get_model (BzInstalledPage *self);

gboolean
bz_installed_page_ensure_active (BzInstalledPage *self,
                                 const char      *initial);

G_END_DECLS
